@@ -9,42 +9,39 @@ import pafy
 from time import sleep, time
 @click.group(
     cls=HelpColorsGroup, help_headers_color="yellow", help_options_color="cyan")
-@click.version_option('0.1.1')
+@click.version_option('0.1.2')
 def main():
     """PowerPlayer - Play music in your terminal"""
 @main.command('playfromyt', help = 'Play music from youtube. Give the song name')
 @click.argument('song', nargs = 1)
 def playfromyt(song):
+    
     music_name = song
     query_string = urllib.parse.urlencode({"search_query": music_name})
     formatUrl = urllib.request.urlopen("https://www.youtube.com/results?" + query_string)
     search_results = re.findall(r"watch\?v=(\S{11})", formatUrl.read().decode())
     clip = requests.get("https://www.youtube.com/watch?v=" + "{}".format(search_results[0]))
     clip2 = "https://www.youtube.com/watch?v=" + "{}".format(search_results[0])
-
     inspect = BeautifulSoup(clip.content, "html.parser")
     yt_title = inspect.find_all("meta", property="og:title")
-
     for concatMusic1 in yt_title:
         pass
 
     
     click.secho(clip2)
-    dir = os.path.join(os.path.expanduser("~"), ".powerplayer", "Audio")
     video = pafy.new(clip2)
-
     best = video.getbestaudio()
-    player = vlc.Instance()
-    # creating vlc media player object
+    instance = vlc.Instance()
+    
     media = vlc.MediaPlayer(best.url)
     click.secho(f'Playing...')
     click.secho(concatMusic1['content'])
     media.play()
     start = time()
-    while (time() - start < 100001):
-        sleep(100001 - (time() - start))
-  
-
+    while (time() - start < 100000):
+        sleep(100000 - (time() - start))
+    
+    
 @main.command('playfrompc', help = "Play an audio file in your pc")
 @click.argument('dir', nargs = 1)
 def playfrompc(dir):
